..
    Copyright (C) 2021 CERN.
    Copyright (C) 2019-2024 Esteban J. Garcia Gabancho.
    Copyright (C) 2024 Graz University of Technology.

    Invenio-SAML is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Changes
=======


Version 1.1.0 (release 2025-05-08)
- updates version requirements to support newer invenio module versions
- handlers: allow user lookup customizing in factory
- profile: add affiliations profile value
- adds test version restrictions to minimize xmlsec issues

Version 1.0.1 (release 2024-11-30)

- setup: change to reusable workflows
- setup: pin dependencies
- docs: explicitly add python requirements

Version 1.0.0 (released 2024-04-10)

- Initial stable release.

Version 1.0.0a4 (released 2022-12-15)

- Migrate Flask-SSO-SAML code #31
- Check before linking user #35
- Add translations tests #36

Version 1.0.0a2 (released 2022-09-12)

- Add auto_confirm, confirm user email address

Version 1.0.0a1 (released 2021-07-15)

- Marking strings for translation
- Adds german translation

Version 1.0.0a0 (released 2021-05-27)

- Module refactoring.

Version 0.1.0 (released TBD)

- Initial public release.
